==> ros-dashing-behaviortree-cpp_2.5.2.orig.tar.gz: ros-dashing-behaviortree-cpp-2.5.2/src/condition_node.cpp <==
/* Copyright (C) 2015-2018 Michele Colledanchise -  All Rights Reserved
 * Copyright (C) 2018 Davide Faconti -  All Rights Reserved
*
*   Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"),
*   to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense,
*   and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
*   The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
*
*   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
*   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
*   WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

#include "behaviortree_cpp/condition_node.h"

namespace BT
{
ConditionNode::ConditionNode(const std::string& name, const NodeParameters& parameters)
  : LeafNode::LeafNode(name, parameters)
{
}

void ConditionNode::halt()
{
}

SimpleConditionNode::SimpleConditionNode(const std::string& name, TickFunctor tick_functor,
                                         const NodeParameters &params)
  : ConditionNode(name, params), tick_functor_(std::move(tick_functor))
{
}

NodeStatus SimpleConditionNode::tick()
{
    return tick_functor_(*this);
}
}

==> ros-dashing-behaviortree-cpp-v3_3.1.1.orig.tar.gz: ros-dashing-behaviortree-cpp-v3-3.1.1/src/condition_node.cpp <==
/* Copyright (C) 2015-2018 Michele Colledanchise -  All Rights Reserved
 * Copyright (C) 2018-2019 Davide Faconti, Eurecat -  All Rights Reserved
*
*   Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"),
*   to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense,
*   and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
*   The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
*
*   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
*   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
*   WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

#include "behaviortree_cpp_v3/condition_node.h"

namespace BT
{
ConditionNode::ConditionNode(const std::string& name, const NodeConfiguration& config)
  : LeafNode::LeafNode(name, config)
{
}

SimpleConditionNode::SimpleConditionNode(const std::string& name, TickFunctor tick_functor,
                                         const NodeConfiguration& config)
  : ConditionNode(name, config), tick_functor_(std::move(tick_functor))
{
}

NodeStatus SimpleConditionNode::tick()
{
    return tick_functor_(*this);
}
}
